==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkPointPlacer.java <==
// java wrapper for vtkPointPlacer object
//

package vtk;
import vtk.*;

public class vtkPointPlacer extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int ComputeWorldPosition_2(vtkRenderer id0,double id1[],double id2[],double id3[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[])
    { return ComputeWorldPosition_2(id0,id1,id2,id3); }

  private native int ComputeWorldPosition_3(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[])
    { return ComputeWorldPosition_3(id0,id1,id2,id3,id4); }

  private native int ValidateWorldPosition_4(double id0[]);
  public int ValidateWorldPosition(double id0[])
    { return ValidateWorldPosition_4(id0); }

  private native int ValidateDisplayPosition_5(vtkRenderer id0,double id1[]);
  public int ValidateDisplayPosition(vtkRenderer id0,double id1[])
    { return ValidateDisplayPosition_5(id0,id1); }

  private native int ValidateWorldPosition_6(double id0[],double id1[]);
  public int ValidateWorldPosition(double id0[],double id1[])
    { return ValidateWorldPosition_6(id0,id1); }

  private native int UpdateWorldPosition_7(vtkRenderer id0,double id1[],double id2[]);
  public int UpdateWorldPosition(vtkRenderer id0,double id1[],double id2[])
    { return UpdateWorldPosition_7(id0,id1,id2); }

  private native int UpdateNodeWorldPosition_8(double id0[],int id1);
  public int UpdateNodeWorldPosition(double id0[],int id1)
    { return UpdateNodeWorldPosition_8(id0,id1); }

  private native int UpdateInternalState_9();
  public int UpdateInternalState()
    { return UpdateInternalState_9(); }

  private native void SetPixelTolerance_10(int id0);
  public void SetPixelTolerance(int id0)
    { SetPixelTolerance_10(id0); }

  private native int GetPixelToleranceMinValue_11();
  public int GetPixelToleranceMinValue()
    { return GetPixelToleranceMinValue_11(); }

  private native int GetPixelToleranceMaxValue_12();
  public int GetPixelToleranceMaxValue()
    { return GetPixelToleranceMaxValue_12(); }

  private native int GetPixelTolerance_13();
  public int GetPixelTolerance()
    { return GetPixelTolerance_13(); }

  private native void SetWorldTolerance_14(double id0);
  public void SetWorldTolerance(double id0)
    { SetWorldTolerance_14(id0); }

  private native double GetWorldToleranceMinValue_15();
  public double GetWorldToleranceMinValue()
    { return GetWorldToleranceMinValue_15(); }

  private native double GetWorldToleranceMaxValue_16();
  public double GetWorldToleranceMaxValue()
    { return GetWorldToleranceMaxValue_16(); }

  private native double GetWorldTolerance_17();
  public double GetWorldTolerance()
    { return GetWorldTolerance_17(); }

  public vtkPointPlacer() { super(); }

  public vtkPointPlacer(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkPointPlacer.java <==
// java wrapper for vtkPointPlacer object
//

package vtk;
import vtk.*;

public class vtkPointPlacer extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int ComputeWorldPosition_2(vtkRenderer id0,double id1[],double id2[],double id3[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[])
    { return ComputeWorldPosition_2(id0,id1,id2,id3); }

  private native int ComputeWorldPosition_3(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[])
    { return ComputeWorldPosition_3(id0,id1,id2,id3,id4); }

  private native int ValidateWorldPosition_4(double id0[]);
  public int ValidateWorldPosition(double id0[])
    { return ValidateWorldPosition_4(id0); }

  private native int ValidateDisplayPosition_5(vtkRenderer id0,double id1[]);
  public int ValidateDisplayPosition(vtkRenderer id0,double id1[])
    { return ValidateDisplayPosition_5(id0,id1); }

  private native int ValidateWorldPosition_6(double id0[],double id1[]);
  public int ValidateWorldPosition(double id0[],double id1[])
    { return ValidateWorldPosition_6(id0,id1); }

  private native int UpdateWorldPosition_7(vtkRenderer id0,double id1[],double id2[]);
  public int UpdateWorldPosition(vtkRenderer id0,double id1[],double id2[])
    { return UpdateWorldPosition_7(id0,id1,id2); }

  private native int UpdateNodeWorldPosition_8(double id0[],int id1);
  public int UpdateNodeWorldPosition(double id0[],int id1)
    { return UpdateNodeWorldPosition_8(id0,id1); }

  private native int UpdateInternalState_9();
  public int UpdateInternalState()
    { return UpdateInternalState_9(); }

  private native void SetPixelTolerance_10(int id0);
  public void SetPixelTolerance(int id0)
    { SetPixelTolerance_10(id0); }

  private native int GetPixelToleranceMinValue_11();
  public int GetPixelToleranceMinValue()
    { return GetPixelToleranceMinValue_11(); }

  private native int GetPixelToleranceMaxValue_12();
  public int GetPixelToleranceMaxValue()
    { return GetPixelToleranceMaxValue_12(); }

  private native int GetPixelTolerance_13();
  public int GetPixelTolerance()
    { return GetPixelTolerance_13(); }

  private native void SetWorldTolerance_14(double id0);
  public void SetWorldTolerance(double id0)
    { SetWorldTolerance_14(id0); }

  private native double GetWorldToleranceMinValue_15();
  public double GetWorldToleranceMinValue()
    { return GetWorldToleranceMinValue_15(); }

  private native double GetWorldToleranceMaxValue_16();
  public double GetWorldToleranceMaxValue()
    { return GetWorldToleranceMaxValue_16(); }

  private native double GetWorldTolerance_17();
  public double GetWorldTolerance()
    { return GetWorldTolerance_17(); }

  public vtkPointPlacer() { super(); }

  public vtkPointPlacer(long id) { super(id); }
  public native long   VTKInit();

}
